@@ -4,7 +4,6 @@ OC.L10N.register(
     "Provided email-address is not valid" : "Alamat surel tidak valid",
     "%s has published the calendar »%s«" : "%s telah mempublikasikan kalender »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim surel. Silakan hubungi administrator Anda.",
-    "Successfully sent email to " : "Berhasil mengirim surel ke",
     "Hello," : "Halo,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan anda bahwa %s telah mempublikasikan kalender »%s«.",
     "Open »%s«" : "Buka »%s«",
@@ -73,6 +72,7 @@ OC.L10N.register(
     "Creating subscription …" : "Membuat langganan …",
     "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
+    "Untitled event" : "Acara tanpa judul",
     "Import calendars" : "Impor kalender",
     "Filename" : "Nama berkas",
     "Cancel" : "Batal",
@@ -126,35 +126,25 @@ OC.L10N.register(
     "_week_::_weeks_" : ["minggu"],
     "No reminders yet" : "Belum ada pengingat",
     "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
+    "Free" : "Luang",
     "Busy (tentative)" : "Sibuk (tentatif)",
     "Busy" : "Sibuk",
     "Out of office" : "Keluar kantor",
     "Unknown" : "Tidak diketahui",
-    "{name} accepted your invitation." : "{name} menerima undangan Anda.",
-    "{name} accepted {organizerName}'s invitation." : "{name} menerima undangan {organizerName}.",
-    "{name} declined your invitation." : "{name} menolak undangan Anda.",
-    "{name} declined {organizerName}'s invitation." : "{name} menolak undangan {organizerName}.",
-    "{name} has delegated their invitation." : "{name} telah mendelegasikan undangannya.",
-    "{name} marked their participation as tentative." : "{name} menandai partisipasinya sebagai tentatif.",
-    "{name} did not respond to your invitation yet." : "{name} belum menanggapi undangan Anda.",
-    "{name} did not respond to {organizerName}'s invitation yet." : "{name} belum menanggapi undangan {organizerName}.",
     "Create Talk room for this event" : "Buat ruangan Talk untuk acara ini",
     "Show busy times" : "Tampilkan waktu sibuk",
     "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
     "Error creating Talk room" : "Galat membuat ruangan Talk",
-    "Send e-mail" : "Kirim surel",
     "Required participant" : "Partisipan wajib",
     "Optional participant" : "Partisipan opsional",
     "Non-participant" : "Bukan partisipan",
     "Remove attendee" : "Hapus peserta",
-    "Search for e-mails, users, contacts, resources or rooms" : "Cari surel, pengguna, kontak, sumber lain atau ruangan",
     "No match found" : "Tidak ditemukan kecocokan",
     "No attendees yet" : "Belum ada peserta",
     "(organizer)" : "(penyelenggara)",
     "Remove color" : "Hapus warna",
     "Event title" : "Judul acara",
     "All day" : "Sepanjang hari",
-    "Can not modify all-day setting for events that are part of a recurrence-set." : "Tidak dapat mengubah setelan sepanjang hari, dari rangkaian acara berulang.",
     "End repeat" : "Akhiri perulangan",
     "Select to end repeat" : "Pilih untuk mengakhiri perulangan",
     "never" : "tidak pernah",
@@ -237,10 +227,8 @@ OC.L10N.register(
     "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["pada hari {dayOfMonthList}"],
     "until {untilDate}" : "sampai {untilDate}",
     "_%n time_::_%n times_" : ["%n kali"],
-    "Untitled event" : "Acara tanpa judul",
     "Untitled task" : "Tugas tanpa judul",
     "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
-    "today" : "hari ini",
     "_+%n more_::_+%n more_" : ["+%n lagi"],
     "Location" : "Lokasi",
     "Add a location" : "Tambah lokasi",
@@ -252,7 +240,6 @@ OC.L10N.register(
     "Confirmation about the overall status of the event." : "Konfirmasi tentang status keseluruhan acara.",
     "Show as" : "Tampilkan sebagai",
     "Take this event into account when calculating free-busy information." : "Pertimbangkan acara ini saat perhitungan waktu luang dan sibuk.",
-    "Free" : "Luang",
     "Categories" : "Kategori",
     "Categories help you to structure and organize your events." : "Kategori membantu Anda menyusun dan mengatur acara.",
     "Search or add categories" : "Cari atau tambah kategori",
